==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSNetworkLoadBalancerParametersBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AWSNetworkLoadBalancerParametersBuilder extends io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder>{
  public AWSNetworkLoadBalancerParametersBuilder() {
    this(false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(java.lang.Boolean validationEnabled) {
    this(new AWSNetworkLoadBalancerParameters(), validationEnabled);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AWSNetworkLoadBalancerParameters(), validationEnabled);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance) {
    this(fluent, instance, false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance) {
    this(instance,false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters build() {
    AWSNetworkLoadBalancerParameters buildable = new AWSNetworkLoadBalancerParameters();
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AWSNetworkLoadBalancerParametersBuilder that = (AWSNetworkLoadBalancerParametersBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSNetworkLoadBalancerParametersBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AWSNetworkLoadBalancerParametersBuilder extends io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersBuilder>{
  public AWSNetworkLoadBalancerParametersBuilder() {
    this(false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(java.lang.Boolean validationEnabled) {
    this(new AWSNetworkLoadBalancerParameters(), validationEnabled);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AWSNetworkLoadBalancerParameters(), validationEnabled);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance) {
    this(fluent, instance, false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance) {
    this(instance,false);
  }
  public AWSNetworkLoadBalancerParametersBuilder(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters build() {
    AWSNetworkLoadBalancerParameters buildable = new AWSNetworkLoadBalancerParameters();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AWSNetworkLoadBalancerParametersBuilder that = (AWSNetworkLoadBalancerParametersBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
